@@ -16,7 +16,6 @@ from __future__ import absolute_import
 from tobiko.openstack.glance import _client
 from tobiko.openstack.glance import _image
 from tobiko.openstack.glance import _io
-from tobiko.openstack.glance import _lzma
 
 
 glance_client = _client.glance_client
@@ -28,12 +27,8 @@ find_image = _client.find_image
 list_images = _client.list_images
 delete_image = _client.delete_image
 
-FileGlanceImageFixture = _image.FileGlanceImageFixture
 GlanceImageFixture = _image.GlanceImageFixture
 HasImageMixin = _image.HasImageMixin
-URLGlanceImageFixture = _image.URLGlanceImageFixture
-CustomizedGlanceImageFixture = _image.CustomizedGlanceImageFixture
+UrlGlanceImageFixture = _image.UrlGlanceImageFixture
 
 open_image_file = _io.open_image_file
-
-has_lzma = _lzma.has_lzma
