@@ -38,7 +38,10 @@ NovaHypervisor = typing.Union[novaclient.v2.hypervisors.Hypervisor]
 class NovaClientFixture(_client.OpenstackClientFixture):
 
     def init_client(self, session) -> NovaClient:
-        return novaclient.client.Client('2.56', session=session)
+        return novaclient.client.Client(
+            '2.56',
+            session=session,
+            additional_headers={'Connection': 'close'})
 
 
 class NovaClientManager(_client.OpenstackClientManager):
@@ -380,7 +383,7 @@ def wait_for_server_status(
     for attempt in tobiko.retry(timeout=timeout,
                                 interval=sleep_time,
                                 default_timeout=300.,
-                                default_interval=5.):
+                                default_interval=3.):
         _server = get_server(server_id=server_id, client=client)
         if _server.status == status:
             break
@@ -397,7 +400,7 @@ def wait_for_server_status(
                                              status=status,
                                              timeout=timeout) from ex
 
-        progress = getattr(server, 'progress', None)
+        progress = getattr(_server, 'progress', None)
         LOG.debug(f"Waiting for server {server_id} status to get from "
                   f"{_server.status} to {status} "
                   f"(progress={progress}%)")
