@@ -20,6 +20,7 @@ from oslo_log import log
 
 import tobiko
 from tobiko.openstack import neutron
+from tobiko.openstack import nova
 from tobiko.openstack import topology
 from tobiko.podified import _edpm
 from tobiko.podified import _openshift
@@ -46,10 +47,13 @@ skip_if_podified = tobiko.skip_if(
 # contain all of those "sub groups"
 COMPUTE_GROUPS = [
     _openshift.EDPM_COMPUTE_GROUP,
-    _openshift.EDPM_NETWORKER_GROUP,
     _openshift.EDPM_OTHER_GROUP
 ]
+NETWORKER_GROUPS = [
+    _openshift.EDPM_NETWORKER_GROUP,
+]
 ALL_COMPUTES_GROUP_NAME = 'compute'
+ALL_NETWORKERS_GROUP_NAME = 'networker'
 OCP_NODE = 'ocp_node'
 EDPM_NODE = 'edpm_node'
 
@@ -67,9 +71,18 @@ class PodifiedTopology(rhosp.RhospTopology):
         neutron.NEUTRON_OVN_AGENT: 'edpm_ovn_agent',
         neutron.OVN_CONTROLLER: 'edpm_ovn_controller',
         neutron.OVN_BGP_AGENT: 'edpm_ovn_bgp_agent',
-        neutron.FRR: 'edpm_frr'
+        neutron.FRR: 'edpm_frr',
+        nova.ISCSID: '',
+        nova.NOVA_COMPUTE: 'edpm_nova_compute'
     }
 
+    @classmethod
+    def get_agent_service_name(cls, agent_name: str) -> str:
+        # Handle nova.ISCSID specially since it's configurable
+        if agent_name == nova.ISCSID:
+            return tobiko.tobiko_config().podified.edpm_iscsid_service_name
+        return super().get_agent_service_name(agent_name)
+
     # NOTE(slaweq): those container names are only valid for the EDPM nodes
     agent_to_container_name_mappings = {
         neutron.DHCP_AGENT: 'neutron_dhcp',
@@ -123,12 +136,17 @@ class PodifiedTopology(rhosp.RhospTopology):
             **create_params
         )
         # NOTE(slaweq): additionally lets add every edpm node to the "legacy"
-        # group named "compute"
+        # groups named "compute" or "networker"
         if group and group in COMPUTE_GROUPS:
             group_nodes = self.add_group(group=ALL_COMPUTES_GROUP_NAME)
             if node and node not in group_nodes:
                 group_nodes.append(node)
                 node.add_group(group=ALL_COMPUTES_GROUP_NAME)
+        if group and group in NETWORKER_GROUPS:
+            group_nodes = self.add_group(group=ALL_NETWORKERS_GROUP_NAME)
+            if node and node not in group_nodes:
+                group_nodes.append(node)
+                node.add_group(group=ALL_NETWORKERS_GROUP_NAME)
         return node
 
     def create_node(self, name, ssh_client, **kwargs):
